@@ -207,7 +207,7 @@ def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batc
 			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr)}")
 			history = model.fit(get_training_dataset(GCS_DS_PATH, train_tfrec_path, batch_size, augmentation = True), validation_data = get_validation_dataset(GCS_DS_PATH, val_tfrec_path, batch_size, augmentation = True), epochs = 1, steps_per_epoch = steps_per_epoch, batch_size = batch_size, verbose = 1)
 			if callbacks is not None:
-				set_learning_rate(model, epoch + 1, callbacks)
+				set_learning_rate(model, epoch + 1)
 			
 			for k,v in history.history.items():
 				overall[k] = v
@@ -219,7 +219,7 @@ def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batc
 			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr)}")
 			history = model.fit(get_training_dataset(GCS_DS_PATH, train_tfrec_path, batch_size, augmentation = True), validation_data = get_validation_dataset(GCS_DS_PATH, val_tfrec_path, batch_size, augmentation = True), epochs = 1, steps_per_epoch = steps_per_epoch, batch_size = batch_size, verbose = 1)
 			if callbacks is not None:
-				set_learning_rate(model, epoch + 1, callbacks)
+				set_learning_rate(model, epoch + 1)
 			
 			for k,v in history.history.items():
 				overall[k].extend(v)
